<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">
<html>
<head>
  <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
  <meta http-equiv="Content-Style-Type" content="text/css">
  <title></title>
  <meta name="Generator" content="Cocoa HTML Writer">
  <meta name="CocoaVersion" content="1344.72">
  <style type="text/css">
    p.p1 {margin: 0.0px 0.0px 0.0px 0.0px; font: 12.0px Arial; color: #000000; -webkit-text-stroke: #000000}
    p.p2 {margin: 0.0px 0.0px 0.0px 0.0px; font: 12.0px Arial; color: #0000ee; -webkit-text-stroke: #0000ee}
    p.p3 {margin: 0.0px 0.0px 12.0px 0.0px; font: 12.0px Times; color: #000000; -webkit-text-stroke: #000000}
    p.p4 {margin: 0.0px 0.0px 0.0px 0.0px; font: 12.0px Arial; color: #000000; -webkit-text-stroke: #000000; min-height: 14.0px}
    p.p5 {margin: 0.0px 0.0px 0.0px 0.0px; font: 12.0px Courier; color: #942192; -webkit-text-stroke: #000000}
    p.p6 {margin: 0.0px 0.0px 12.0px 0.0px; font: 12.0px Courier; color: #942192; -webkit-text-stroke: #000000}
    p.p7 {margin: 0.0px 0.0px 0.0px 0.0px; font: 10.0px Monaco; color: #942192; -webkit-text-stroke: #942192}
    p.p8 {margin: 0.0px 0.0px 0.0px 0.0px; font: 12.0px Courier; color: #000000; -webkit-text-stroke: #000000}
    p.p9 {margin: 0.0px 0.0px 0.0px 0.0px; font: 12.0px Arial}
    p.p10 {margin: 0.0px 0.0px 0.0px 0.0px; font: 12.0px Arial; color: #942192; -webkit-text-stroke: #000000}
    p.p11 {margin: 0.0px 0.0px 0.0px 0.0px; font: 12.0px Arial; color: #942192; -webkit-text-stroke: #000000; min-height: 14.0px}
    p.p12 {margin: 0.0px 0.0px 0.0px 0.0px; font: 12.0px Arial; -webkit-text-stroke: #000000}
    p.p13 {margin: 0.0px 0.0px 0.0px 0.0px; font: 12.0px Arial; -webkit-text-stroke: #000000; min-height: 14.0px}
    p.p14 {margin: 0.0px 0.0px 0.0px 0.0px; font: 12.0px Courier; color: #942192}
    p.p15 {margin: 0.0px 0.0px 0.0px 0.0px; font: 12.0px Courier; -webkit-text-stroke: #000000; min-height: 14.0px}
    p.p16 {margin: 0.0px 0.0px 0.0px 0.0px; font: 15.0px Helvetica; color: #000000; -webkit-text-stroke: #000000}
    span.s1 {font-kerning: none}
    span.s2 {font-kerning: none; color: #000000; -webkit-text-stroke: 0px #000000}
    span.s3 {text-decoration: underline ; font-kerning: none; color: #0000ee; -webkit-text-stroke: 0px #0000ee}
    span.s4 {text-decoration: underline ; font-kerning: none}
    span.s5 {font: 12.0px Arial; font-kerning: none; color: #000000}
    span.s6 {font: 12.0px Helvetica; font-kerning: none}
    span.s7 {font-kerning: none; color: #000000}
    span.s8 {font: 12.0px Courier; font-kerning: none; color: #942192}
    span.s9 {font-kerning: none; -webkit-text-stroke: 0px #000000}
    span.s10 {font: 12.0px Arial; font-kerning: none}
    span.s11 {font-variant-ligatures: no-common-ligatures}
  </style>
</head>
<body>
<?php
//  comment in phpp ..
include 'phpfiles.php';
?>

<p class="p1"><b>Installation from a pkg<span class="Apple-converted-space">  </span>file is standard,</b></p>
<br>
<p class="p1">   on precompile version FreeFem++-3.60-MacOS_10.13.pkg to use petsc/slepc 
        you need to install XQuartz 
        form <a href="https://dl.bintray.com/xquartz/downloads/XQuartz-2.7.11.dmg"> XQuartz-2.7.11.dmg </a></p>
<p class="p1"><br><b>Remark </b>on version 10.10, 10.9 and 10.8 to authorise the install from everywhere <a href="http://maypalo.com/2013/1
0/28/install-non-approved-apps-mavericks-10-9/"> (see System Preferences > Security & Privacy > General > Allow applications dow
nloaded from > Anywhere)<A> 


<br><p class="p1">Take the file from and download </p> 
	<? pfile($m13file,"MacOS 10.13 (with openmpi,petc), ifort MKL     ") ?>		
	<? pfile($m12file,"MacOS 10.12 (with openmpi,petc), ifort MKL     ") ?>		
	<? pfile($m11file,"MacOS 10.11 (with openmpi,petc), ifort MKL     ") ?>		
	<? pfile($m10file,"MacOS 10.10 (with openmpi,petc), ifort MKL    ") ?>		
	<? pfile($m9file,"MacOS 10.9 (with mpich), ifort MKL   ") ?>		
	<? pfile($m8file,"MacOS 10.8") ?>		
	<? pfile($m7file,"MacOS 10.7") ?>		
	<? pfile($m6file,"MacOS 10.6") ?>	
	<? pfile($mfile,"MacOS 10.4") ?>	
<p class="p1"><br></p>
<p class="p1">The <tt>textmate 2</tt> editor is a good editor for  Mac 10.7 or better, <a href="https://macromates.com/download"> download  from macromates.com </a> and install it, when  get the 
  <a href="http://www.freefem.org/ff++/Textmate2-ff++.zip"> textmate freefem++ syntax from www.freefem.org/ff++/Textmate2-ff++.zip (version nov.  2107)</a> unzip Textmate2-ff++.zip and follow the explanation given in file \texttt{How\_To.rtf}.</p>
<p class="p1"><br></p>

<p class="p1"><span class="s1"> Please read the <a href="README_MAC.txt"> README_MAC</a> form the distribution for the full infomation </span></p>
<p class="p1"><span class="s1">Take the file from and download<span class="Apple-converted-space"> </span></span></p>
<p class="p3"><span class="s1"><br>
</span></p>
<p class="p1"><span class="s1">remark,<span class="Apple-converted-space">  </span>all examples and documentation are in the directory</span></p>
<p class="p2"><span class="s2"><span class="Apple-converted-space"> </span><a href="file:///usr/local/share/freefem++"><span class="s3">file:///usr/local/share/freefem++</span></a></span></p>
<p class="p1"><span class="s1">the library install file are in<span class="Apple-converted-space"> </span></span></p>
<p class="p2"><span class="s4"><a href="file:///usr/local/lib/ff++">file:///usr/local/lib/ff++</a></span></p>
<p class="p1"><span class="s1"><br>
</span></p>
<p class="p1"><span class="s1"><br>
</span></p>
<p class="p1"><span class="s1"><b>(In progress (May 2018 FH) ) To compile a full version of FreeFem++ under MacOS<span class="Apple-converted-space"> </span></b></span></p>
<p class="p1"><span class="s1">---------------------------------------------------------------------------</span></p>
<p class="p1"><span class="s1">First download the tar.gz file contening source from<span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1">or you can get the latest source from an anonymous <A href="https://git-scm.com/downloads" > git SCM </A> copy with the following unix shell commands :</span></p>
<p class="p6"><span class="s1"># git clone https://github.com/FreeFem/FreeFem-sources ff++<span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><b>Under Hight Sierra or better<span class="Apple-converted-space">  </span>(10.13)<span class="Apple-converted-space">  </span>2015 ( xcode 9.3 <span class="Apple-converted-space">  </span>form scratch)</b></span></p>
<p class="p1"><span class="s1"><b>-------------------------------------------------</b></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>remark: All line beginning by # are<span class="Apple-converted-space">  </span>shell command in terminal.<span class="Apple-converted-space"> </span></span></p>
<p class="p4"><span class="s1"><span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><br>
</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>1) install xcode  ,<span class="Apple-converted-space"> </span></span></p>
<p class="p4"><span class="s1"></span><br></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>2) to install<span class="Apple-converted-space">  </span>the xcode command line tools <span class="Apple-converted-space"> </span></span></p>
<p class="p4"><span class="s1"></span><br></p>
<p class="p5"><span class="s1">#<span class="Apple-converted-space">  </span>gcc<span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1">answer to the dialogue<span class="Apple-converted-space">  </span>box</span></p>
<p class="p1"><span class="s1">to check after</span></p>
<p class="p7"><span class="s1"># clang++ -v</span></p>
<p class="p8"><span class="s1">Apple LLVM version 9.1.0 (clang-902.0.39.1)</span></p>
<p class="p8"><span class="s1">Target: x86_64-apple-darwin17.5.0</span></p>
<p class="p8"><span class="s1">Thread model: posix</span></p>
<p class="p8"><span class="s1">InstalledDir: /Applications/Xcode.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin</span></p>
<p class="p1"><span class="s1"><br>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span>3) install<span class="Apple-converted-space">  </span>ifort or gfortran with brew installer</p>
<p class="p1"><span class="s1"><br>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>4) install </span><span class="s6">mpich or openmpi<span class="Apple-converted-space"> </span></span><span class="s1"> form the source<span class="Apple-converted-space"> </span></span></p>
<p class="p4"><span class="s1"><span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1">get :</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span>http://www.mpich.org/static/downloads/3.1.3/mpich-3.2..tar.gz</span></p>
<p class="p1"><span class="s1">or<span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span>https://www.open-mpi.org/software/ompi/v3.0/downloads/openmpi-3.0.1.tar.gz</span></p>
<p class="p1"><span class="s1">un tar and:<span class="Apple-converted-space"> </span></span></p>
<p class="p5"><span class="s1"><span class="Apple-converted-space">  </span>#<span class="Apple-converted-space">  </span>./configure 'F77=gfortran' 'FC=gfortran' 'CC=clang' 'CXX=clang++'</span></p>
<p class="p5"><span class="s1"><span class="Apple-converted-space">  </span># make<span class="Apple-converted-space"> </span></span></p>
<p class="p5"><span class="s1"><span class="Apple-converted-space">  </span># sudo make install</span></p>
<p class="p1"><span class="s1">remark: you can no use precompile version because the fortran in not correct.<br>
</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>5) install gsl<span class="Apple-converted-space"> </span></span></p>
<p class="p9"><span class="s2"><span class="Apple-converted-space">   </span>use homebrew (</span><span class="s1">http://brew.sh ) or do:</span></p>
<p class="p4"><span class="s1"></span><br></p>
<p class="p5"><span class="s7"><span class="Apple-converted-space"> </span></span><span class="s1"> # curl -O http://git.savannah.gnu.org/cgit/gsl.git/snapshot/gsl-release-2-4.tar.gz</span></p>
<p class="p5"><span class="s1"><span class="Apple-converted-space">  </span># tar zxvf gsl-release-2-4.tar.gz</span></p>
<p class="p5"><span class="s1"><span class="Apple-converted-space">  </span># cd gsl-release-2-4.tar.gz</span></p>
<p class="p5"><span class="s1"><span class="Apple-converted-space">  </span>#./configure CC=clang</span></p>
<p class="p5"><span class="s1"><span class="Apple-converted-space">  </span># make</span></p>
<p class="p5"><span class="s1"><span class="Apple-converted-space">  </span># sudo make install<span class="Apple-converted-space"> </span></span></p>
<p class="p5"><span class="s1"><br>
</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>6) Install git from the web <A href="https://git-scm.com/downloads" > https://git-scm.com/downloads </A>/span></p>
<p class="p4"><span class="s1"><span class="Apple-converted-space">    </span></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>7)<span class="Apple-converted-space">  </span>Download freefem++ <span class="Apple-converted-space"> </span></span></p>
<p class="p4"><span class="s1"></span><br></p>
<p class="p10"><span class="s1"><span class="Apple-converted-space">  </span># git clone https://github.com/FreeFem/FreeFem-sources ff++</span></p>
<p class="p11"><span class="s1"></span><br></p>
<p class="p12"><span class="s1"><span class="Apple-converted-space">  </span>9) install autoconf and automake now not in xcode</span></p>
<p class="p13"><span class="s1"></span><br></p>
<p class="p12"><span class="s1"><span class="Apple-converted-space">   </span>I use the macport <span class="Apple-converted-space">  </span>distribution form http://www.macports.org</span></p>
<p class="p12"><span class="s1"><span class="Apple-converted-space">    </span>or the home brew distribution from http://brew.sh</span></p>
<p class="p10"><span class="s7"><span class="Apple-converted-space"> </span></span><span class="s1"><span class="Apple-converted-space">  </span># sudo port install<span class="Apple-converted-space">  </span>autoconf</span></p>
<p class="p10"><span class="s1"><span class="Apple-converted-space">   </span># sudo port install<span class="Apple-converted-space">  </span>automake</span></p>
<p class="p12"><span class="s1"><span class="Apple-converted-space">  </span>and to build<span class="Apple-converted-space">  </span>the file<span class="Apple-converted-space">  </span></span><span class="s8">./configure </span><span class="s9">with automake/autoconf<span class="Apple-converted-space">  </span>do<span class="Apple-converted-space"> </span></span></p>
<p class="p14"><span class="s5"><span class="Apple-converted-space">  </span></span><span class="s1"># cd ff++</span></p>
<p class="p5"><span class="s7"><span class="Apple-converted-space"> </span></span><span class="s1"># autoreconf <span class="Apple-converted-space"> </span></span></p>
<p class="p15"><span class="s1"></span><br></p>
<p class="p12"><span class="s1"><span class="Apple-converted-space">  </span>9bis) Or<span class="Apple-converted-space">  </span>untar AutoGeneratedFile.tar.gz</span></p>
<p class="p13"><span class="s1"></span><br></p>
<p class="p5"><span class="s1"><span class="Apple-converted-space"> </span># cd ff++</span></p>
<p class="p5"><span class="s10"><span class="Apple-converted-space">  </span></span><span class="s1"># </span><span class="s11">tar zxvf AutoGeneratedFile.tar.gz<span class="Apple-converted-space"> </span></span></p>
<p class="p10"><span class="s1"><br>
</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>10)<span class="Apple-converted-space">  </span>compilation of freefem++<span class="Apple-converted-space"> </span></span></p>
<p class="p4"><span class="s1"></span><br></p>
<p class="p5"><span class="s1"><span class="Apple-converted-space">  </span># cd ff++</span></p>
<p class="p5"><span class="s1"><span class="Apple-converted-space">  </span>#<span class="Apple-converted-space">  </span>./configure -—enable-download<span class="Apple-converted-space"> </span></span></p>
<p class="p5"><span class="s1"><span class="Apple-converted-space">  </span># make</span></p>
<p class="p5"><span class="s1"><span class="Apple-converted-space">  </span># sudo make install</span></p>
<p class="p1"><span class="s1"><br>
</span></p>
<p class="p1"><span class="s1"><br>

<p class="p1"><span class="s1"><br>
</span></p>
<p class="p1"><span class="s1"><b>(Out of Date ) To compile a full version of FreeFem++ under MacOS<span class="Apple-converted-space"> </span></b></span></p>
<p class="p1"><span class="s1">---------------------------------------------------------------------------</span></p>
<p class="p1"><span class="s1">First download the tar.gz file contening source from<span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1">or you can get the latest source from an anonymous <A href="https://git-scm.com/downloads" > git SCM </A> copy with the following unix shell commands :</span></p>
<p class="p6"><span class="s1"># git clone https://github.com/FreeFem/FreeFem-sources ff++<span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><b>Under Mavericks or better<span class="Apple-converted-space">  </span>(10.9,10.10)<span class="Apple-converted-space">  </span>2015 ( xcode 6.1.1<span class="Apple-converted-space">  </span>form scratch)</b></span></p>
<p class="p1"><span class="s1"><b>-------------------------------------------------</b></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>remark: All line beginning by # are<span class="Apple-converted-space">  </span>shell command in terminal.<span class="Apple-converted-space"> </span></span></p>
<p class="p4"><span class="s1"><span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><br>
</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>1) install xcode 6.1.1 ,<span class="Apple-converted-space"> </span></span></p>
<p class="p4"><span class="s1"></span><br></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>2) to install<span class="Apple-converted-space">  </span>the xcode command line tools <span class="Apple-converted-space"> </span></span></p>
<p class="p4"><span class="s1"></span><br></p>
<p class="p5"><span class="s1">#<span class="Apple-converted-space">  </span>gcc<span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1">answer to the dialogue<span class="Apple-converted-space">  </span>box</span></p>
<p class="p1"><span class="s1">to check after</span></p>
<p class="p7"><span class="s1"># gcc -v</span></p>
<p class="p8"><span class="s1">Configured with: --prefix=/Applications/Xcode.app/Contents/Developer/usr --with-gxx-include-dir=/usr/include/c++/4.2.1</span></p>
<p class="p8"><span class="s1">Apple LLVM version 6.0 (clang-600.0.56) (based on LLVM 3.5svn)</span></p>
<p class="p8"><span class="s1">Target: x86_64-apple-darwin14.1.0</span></p>
<p class="p8"><span class="s1">Thread model: posix</span></p>
<p class="p1"><span class="s1"><br>
</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span>4) install<span class="Apple-converted-space">  </span>gcc-4.9 form http://hpc.sourceforge.net</span></p>
<p class="p1"><span class="s1"><br>
</span></p>
<p class="p5"><span class="s5"><span class="Apple-converted-space"> </span></span><span class="s1"> # curl -O http://prdownloads.sourceforge.net/hpc/gfortran-4.9-bin.tar.gz?download</span></p>
<p class="p5"><span class="s1"><span class="Apple-converted-space"> </span># sudo tar zxvf gfortran-4.9-bin.tar.gz -C /</span></p>
<p class="p5"><span class="s1"><br>
</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>5) install tex<span class="Apple-converted-space">  </span>from<span class="Apple-converted-space">  </span>ctan<span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">   </span>http://mirrors.ctan.org/systems/mac/mactex/MacTeX.pkg</span></p>
<p class="p1"><span class="s1"><br>
</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>6) install </span><span class="s6">mpich or openmpi<span class="Apple-converted-space"> </span></span><span class="s1"> form the source<span class="Apple-converted-space"> </span></span></p>
<p class="p4"><span class="s1"><span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1">get :</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span>http://www.mpich.org/static/downloads/3.1.3/mpich-3.1.3.tar.gz</span></p>
<p class="p1"><span class="s1">or<span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span>http://www.open-mpi.org/software/ompi/v1.6/downloads/openmpi-1.6.5.tar.bz2</span></p>
<p class="p1"><span class="s1">un tar and:<span class="Apple-converted-space"> </span></span></p>
<p class="p5"><span class="s1"><span class="Apple-converted-space">  </span>#<span class="Apple-converted-space">  </span>./configure 'F77=gfortran' 'FC=gfortran' 'CC=clang' 'CXX=clang++'</span></p>
<p class="p5"><span class="s1"><span class="Apple-converted-space">  </span># make<span class="Apple-converted-space"> </span></span></p>
<p class="p5"><span class="s1"><span class="Apple-converted-space">  </span># sudo make install</span></p>
<p class="p1"><span class="s1">remark: you can no use precompile version because the fortran in not correct.<br>
</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>7) install gsl<span class="Apple-converted-space"> </span></span></p>
<p class="p9"><span class="s2"><span class="Apple-converted-space">   </span>use homebrew (</span><span class="s1">http://brew.sh ) or do:</span></p>
<p class="p4"><span class="s1"></span><br></p>
<p class="p5"><span class="s7"><span class="Apple-converted-space"> </span></span><span class="s1"> # curl -O http://ftp.gnu.org/gnu/gsl/gsl-1.16.tar.gz</span></p>
<p class="p5"><span class="s1"><span class="Apple-converted-space">  </span># tar zxvf gsl-1.16.tar.gz</span></p>
<p class="p5"><span class="s1"><span class="Apple-converted-space">  </span># cd gsl-1.16.</span></p>
<p class="p5"><span class="s1"><span class="Apple-converted-space">  </span>#./configure CC=clang</span></p>
<p class="p5"><span class="s1"><span class="Apple-converted-space">  </span># make</span></p>
<p class="p5"><span class="s1"><span class="Apple-converted-space">  </span># sudo make install<span class="Apple-converted-space"> </span></span></p>
<p class="p5"><span class="s1"><br>
</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>6) Install git from the web <A href="https://git-scm.com/downloads" > https://git-scm.com/downloads </A>/span></p>
<p class="p4"><span class="s1"><span class="Apple-converted-space">    </span></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>7)<span class="Apple-converted-space">  </span>Download freefem++ <span class="Apple-converted-space"> </span></span></p>
<p class="p4"><span class="s1"></span><br></p>
<p class="p10"><span class="s1"><span class="Apple-converted-space">  </span># git clone https://github.com/FreeFem/FreeFem-sources ff++</span></p>
<p class="p11"><span class="s1"></span><br></p>
<p class="p12"><span class="s1"><span class="Apple-converted-space">  </span>9) install autoconf and automake now not in xcode</span></p>
<p class="p13"><span class="s1"></span><br></p>
<p class="p12"><span class="s1"><span class="Apple-converted-space">   </span>I use the macport <span class="Apple-converted-space">  </span>distribution form http://www.macports.org</span></p>
<p class="p12"><span class="s1"><span class="Apple-converted-space">    </span>or the home brew distribution from http://brew.sh</span></p>
<p class="p10"><span class="s7"><span class="Apple-converted-space"> </span></span><span class="s1"><span class="Apple-converted-space">  </span># sudo port install<span class="Apple-converted-space">  </span>autoconf</span></p>
<p class="p10"><span class="s1"><span class="Apple-converted-space">   </span># sudo port install<span class="Apple-converted-space">  </span>automake</span></p>
<p class="p12"><span class="s1"><span class="Apple-converted-space">  </span>and to build<span class="Apple-converted-space">  </span>the file<span class="Apple-converted-space">  </span></span><span class="s8">./configure </span><span class="s9">with automake/autoconf<span class="Apple-converted-space">  </span>do<span class="Apple-converted-space"> </span></span></p>
<p class="p14"><span class="s5"><span class="Apple-converted-space">  </span></span><span class="s1"># cd ff++</span></p>
<p class="p5"><span class="s7"><span class="Apple-converted-space"> </span></span><span class="s1"># autoreconf <span class="Apple-converted-space"> </span></span></p>
<p class="p15"><span class="s1"></span><br></p>
<p class="p12"><span class="s1"><span class="Apple-converted-space">  </span>9bis) Or<span class="Apple-converted-space">  </span>untar AutoGeneratedFile.tar.gz</span></p>
<p class="p13"><span class="s1"></span><br></p>
<p class="p5"><span class="s1"><span class="Apple-converted-space"> </span># cd ff++</span></p>
<p class="p5"><span class="s10"><span class="Apple-converted-space">  </span></span><span class="s1"># </span><span class="s11">tar zxvf AutoGeneratedFile.tar.gz<span class="Apple-converted-space"> </span></span></p>
<p class="p10"><span class="s1"><br>
</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>10)<span class="Apple-converted-space">  </span>compilation of freefem++<span class="Apple-converted-space"> </span></span></p>
<p class="p4"><span class="s1"></span><br></p>
<p class="p5"><span class="s1"><span class="Apple-converted-space">  </span># cd ff++</span></p>
<p class="p5"><span class="s1"><span class="Apple-converted-space">  </span>#<span class="Apple-converted-space">  </span>./configure -—enable-download<span class="Apple-converted-space"> </span></span></p>
<p class="p5"><span class="s1"><span class="Apple-converted-space">  </span># make</span></p>
<p class="p5"><span class="s1"><span class="Apple-converted-space">  </span># sudo make install</span></p>
<p class="p1"><span class="s1"><br>
</span></p>
<p class="p1"><span class="s1"><br>
</span></p>
<p class="p1"><span class="s1"><b>Under Mavericks (10.9)<span class="Apple-converted-space">  </span>2012 ( xcode 5.0.2 form scratch)</b></span></p>
<p class="p1"><span class="s1"><b>-------------------------------------------------</b></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>remark: All line beginning by # are<span class="Apple-converted-space">  </span>shell command in terminal.<span class="Apple-converted-space"> </span></span></p>
<p class="p4"><span class="s1"><span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><br>
</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>1) install xcode 5.0.2 , and the xcode command line tools <span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">    </span>xcode<span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">    </span>install Auxiliary Tools for Xcode (for PackageMaker)</span></p>
<p class="p16"><span class="s1"><span class="Apple-converted-space"> </span>2) to install command line tools<span class="Apple-converted-space">  </span>do</span></p>
<p class="p3"><span class="s1"><span class="Apple-converted-space">      </span>xcode click Xcode&gt;Open Developer Tool&gt;More Developer Tools.</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>2) install<span class="Apple-converted-space">  </span>gcc-4.9 form http://hpc.sourceforge.net</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># curl -O http://prdownloads.sourceforge.net/hpc/gfortran-4.9-bin.tar.gz?download</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># sudo tar zxvf gfortran-4.9-bin.tar.gz -C /</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>3) autoconf and automake now not in xcode</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">   </span>I use the macport distribution form http://www.macports.org</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># sudo port install<span class="Apple-converted-space">  </span>autoconfo</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># sudo port install<span class="Apple-converted-space">  </span>automake</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span>Or with<span class="Apple-converted-space">  </span>brew tool ...<span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>4) install tex<span class="Apple-converted-space">  </span>from<span class="Apple-converted-space">  </span>ctan<span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">   </span>http://mirrors.ctan.org/systems/mac/mactex/MacTeX.pkg</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>5) install openmpi form the source<span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>http://www.open-mpi.org/software/ompi/v1.6/downloads/openmpi-1.6.5.tar.bz2</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span>#<span class="Apple-converted-space">  </span>./configure CC=/usr/local/bin/gcc CXX=/usr/local/bin/g++ F77=/usr/local/bin/gfortran FC=/usr/local/bin/gfortran</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># make<span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># sudo make install</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>6) install gsl<span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># curl -O http://ftp.gnu.org/gnu/gsl/gsl-1.15.tar.gz</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># tar zxvf gsl-1.15.tar.gz</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># cd gsl-1.15.</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span>#./configure CC=/usr/local/bin/gcc</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># make</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># sudo make install<span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>7) install git from the web <A href="https://git-scm.com/downloads" > https://git-scm.com/downloads </A></span></p>
<p class="p4"><span class="s1"><span class="Apple-converted-space">    </span></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>8)<span class="Apple-converted-space">  </span>downlaod <span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># git clone https://github.com/FreeFem/FreeFem-sources ff++</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>9)<span class="Apple-converted-space">  </span>compilation of freefem++<span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># cd ff++</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># ./configure '-with-suffix=macos-10.8' '-without-fltk' '--enable-download' '--enable-optim' 'MPIRUN=/usr/local/bin/mpirun' '--enable-m64' '--without-x' 'CC=clang -isysroot /Applications/Xcode.app//Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.8.sdk' 'CFLAGS=-mmacosx-version-min=10.8' 'CXXFLAGS=-mmacosx-version-min=10.8 -std=c++11' 'CXX=clang++ -isysroot /Applications/Xcode.app//Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.8.sdk' 'F77=/usr/local/bin/gfortran' 'FC=/usr/local/bin/gfortran' 'MPICXX=/usr/local/bin/mpic++' 'MPICC=/usr/local/bin/mpicc' 'MPIFC=/usr/local/bin/mpif90' 'MPIF77=/usr/local/bin/mpif90' '--enable-maintainer-mode'</span></p>
<p class="p1"><span class="s1"><br>
</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># make</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># make</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># make<span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># sudo make install</span></p>
<p class="p1"><span class="s1"><br>
</span></p>
<p class="p1"><span class="s1">Under Lion August 2012 ( xcode 4.4 form scratch)</span></p>
<p class="p1"><span class="s1">-------------------------------------------------</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>remark: All line beginning by # are<span class="Apple-converted-space">  </span>shell command in terminal.<span class="Apple-converted-space"> </span></span></p>
<p class="p4"><span class="s1"><span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><br>
</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>1) install xcode 4.5.1<span class="Apple-converted-space">  </span>, and the xcode command line tools <span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">    </span>xcode<span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">      </span>menu preferences -&gt; Downloads -&gt; Components -&gt; Command Line Tools<span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">        </span>install</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">    </span>install Auxiliary Tools for Xcode (for PackageMaker)</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>2) install<span class="Apple-converted-space">  </span>gcc-4.8 form http://hpc.sourceforge.net</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># curl -O http://prdownloads.sourceforge.net/hpc/gcc-lion.tar.gz?download</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># sudo tar zxvf gcc-lion.tar.gz -C /</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>3) autoconf and automake now not in xcode</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">   </span>I use the macport distribution form http://www.macports.org</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># sudo port install<span class="Apple-converted-space">  </span>autoconfo</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># sudo port install<span class="Apple-converted-space">  </span>automake</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>4) install tex<span class="Apple-converted-space">  </span>from<span class="Apple-converted-space">  </span>ctan<span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">   </span>http://mirrors.ctan.org/systems/mac/mactex/MacTeX.pkg</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>5) install openmpi form the source<span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">   </span>http://www.open-mpi.org/software/ompi/v1.6/downloads/openmpi-1.6.tar.bz2</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span>#<span class="Apple-converted-space">  </span>./configure CC=/usr/local/bin/gcc CXX=/usr/local/bin/g++ F77=/usr/local/bin/gfortran FC=/usr/local/bin/gfortran</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># make<span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># sudo make install</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>6) install gsl<span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># curl -O http://ftp.gnu.org/gnu/gsl/gsl-1.15.tar.gz</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># tar zxvf gsl-1.15.tar.gz</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># cd gsl-1.15.</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span>#./configure CC=/usr/local/bin/gcc</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># make</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># sudo make install<span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>7) install git from the web <A href="https://git-scm.com/downloads" > git SCM </A></span></p>
<p class="p4"><span class="s1"><span class="Apple-converted-space">    </span></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>8)<span class="Apple-converted-space">  </span>download <span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># git clone https://github.com/FreeFem/FreeFem-sources ff++</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space"> </span>9)<span class="Apple-converted-space">  </span>compilation of freefem++<span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># cd ff++</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># ./configure '-with-suffix=lion' '-without-fltk' '--enable-download' '--enable-optim' 'MPIRUN=/usr/local/bin/mpirun' '--enable-m64' '--without-x' 'CC=/usr/local/bin/gcc' 'CXX=/usr/local/bin/g++' 'F77=/usr/local/bin/gfortran' 'FC=/usr/local/bin/gfortran' <span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># make</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># make</span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># make<span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1"><span class="Apple-converted-space">  </span># sudo make install<span class="Apple-converted-space"> </span></span></p>
<p class="p1"><span class="s1">------------</span></p>
<p class="p16"><span class="s1"><br>
</span></p>
</body>
</html>
